@@ -230,6 +230,8 @@ class Changelog(object):
                     continue
                 for change in other.unreleased.change_blocks[change_type].changes:
                     if change not in self.unreleased.change_blocks[change_type].changes:
+                        if change_type not in unreleased.change_blocks:
+                            unreleased.change_blocks[change_type] = ChangeBlock(change_type=change_type)
                         unreleased.change_blocks[change_type].changes.append(change)
             res.append(unreleased)
         return res
